# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-02 03:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account_keeping', '0003_auto_20171223_0356'),
    ]

    operations = [
        migrations.CreateModel(
            name='Branch',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, verbose_name='Name')),
                ('slug', models.SlugField(max_length=128, verbose_name='Slug')),
            ],
            options={
                'verbose_name_plural': 'Branches',
                'ordering': ['name'],
                'verbose_name': 'Branch',
            },
        ),
    ]
