# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-02 11:14
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('currency_history', '0001_initial'),
        ('account_keeping', '0005_auto_20190102_0349'),
    ]

    operations = [
        migrations.AddField(
            model_name='branch',
            name='currency',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='branches', to='currency_history.Currency', verbose_name='Currency'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='branch',
            name='slug',
            field=models.SlugField(max_length=128, unique=True, verbose_name='Slug'),
        ),
    ]
